@@ -9,8 +9,27 @@ import traceback
 
 from termcolor import colored, cprint
 
-CLI_REQUEST_NAME = "cli-request.json"
+CLI_REQUEST_NAME  = "cli-request.json"
 CLI_RESPONSE_NAME = "cli-response.json"
+HELP_TEXT         = """\
+******************************************************
+*                                                    *
+*              Spark-CLI command list                *
+*                                                    *
+******************************************************
+
+@@help             -- print help
+@@bash             -- execute the buffer as BASH batch
+@@python           -- execute the buffer as python
+@@log <filename>   -- log to local file
+@@clear            -- clear buffer
+@@show             -- show buffer
+@@load <filename>  -- append content of file to the buffer
+@@mode off         -- turn off line mode
+@@mode bash        -- turn on line mode, each line is bash command
+@@mode python      -- turn on line mode, each line is a python code
+@@quit             -- quit Spark-CLI
+"""
 
 def handle_bash(spark, user_input, channel):
     cmd_buffer = '\n'.join(user_input['lines'])
@@ -104,27 +123,8 @@ class CLIHandler:
                 command = input(prompt)
 
                 if command == "@@help":
-                    help_text = """\
-******************************************************
-*                                                    *
-*              Spark-CLI command list                *
-*                                                    *
-******************************************************
-
-@@help             -- print help
-@@bash             -- execute the buffer as BASH batch
-@@python           -- execute the buffer as python
-@@log <filename>   -- log to local file
-@@clear            -- clear buffer
-@@show             -- show buffer
-@@load <filename>  -- append content of file to the buffer
-@@mode off         -- turn off line mode
-@@mode bash        -- turn on line mode, each line is bash command
-@@mode python      -- turn on line mode, each line is a python code
-@@quit             -- quit Spark-CLI
-
-"""
-                    print(help_text)
+                    print(HELP_TEXT)
+                    print("")
                     continue
 
                 if command == "@@quit":
@@ -263,7 +263,7 @@ def cli_main(spark, args, sysops={}):
         CLI_RESPONSE_NAME,
         {
             "status": "ok",
-            "output": "Welcome to Spark-CLI",
+            "output": "Welcome to Spark-CLI\n\n" + HELP_TEXT,
         }
     )
 
